# Container Queries Responsive Images

This module extends the capabilities of the Core's Responsive Image Style by
adding the ability to react to the size of the container (DOM element) in which
the image is displayed, rather than the size of the view-port.

This approach is best suited to page construction based on the Layout Builder
like in [Sobki](https://www.drupal.org/project/sobki) or
[Drupal "starshot" CMS](https://www.drupal.org/about/starshot),
because it is the structuring of the section that determines the size of the
containers.


## Requirements

This module requires the following modules:
- Responsive Image (Core)

This module requires Composer to gather its dependencies.

This module requires the [container-picture-element](https://github.com/Smile-SA/container-picture-element)
library to be placed in the `libraries` folder.


### With Asset Packagist

If you are using the website [Asset Packagist](https://asset-packagist.org), the
composer.json can be like:

```json
{
    "require": {
        "composer/installers": "2.*",
        "oomphinc/composer-installers-extender": "2.*"
    },
    "repositories": {
        "asset-packagist": {
            "type": "composer",
            "url": "https://asset-packagist.org"
        }
    },
    "extra": {
        "installer-paths": {
            "app/libraries/{$name}": [
                "type:drupal-library",
                "type:bower-asset",
                "type:npm-asset"
            ]
        },
        "installer-types": [
            "bower-asset",
            "npm-asset"
        ]
    }
}
```


### With a package repository

You can declare a custom [package repositories](https://getcomposer.org/doc/05-repositories.md#package-2),
Example:

```json
{
    "require": {
        "composer/installers": "2.*"
    },
    "repositories": {
        "npm-asset-container-picture-element": {
            "type": "package",
            "package": {
                "name": "npm-asset/container-picture-element",
                "version": "0.1.0",
                "type": "drupal-library",
                "dist": {
                    "type": "zip",
                    "url": "https://api.github.com/repos/Smile-SA/container-picture-element/zipball/f1b1082c746222d4856f670ab49c3469c7dc86f9",
                    "reference": "f1b1082c746222d4856f670ab49c3469c7dc86f9"
                }
            }
        }
    },
    "extra": {
        "installer-paths": {
            "app/libraries/{$name}": [
                "type:drupal-library"
            ]
        }
    }
}
```


## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Modules](https://www.drupal.org/docs/extending-drupal/installing-modules).


## Configuration

You can now use the `Container Queries Responsive Images` breakpoint in your
responsive image styles.

Configure this breakpoint like with the `Responsive Image` breakpoint from Core.

Then on your image fields, use the new `Container queries responsive image`
formatter and select one responsive image style using the new breakpoint.
