<?php

declare(strict_types=1);

namespace Drupal\cqri\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\responsive_image\Plugin\Field\FieldFormatter\ResponsiveImageFormatter;

/**
 * Plugin for responsive image formatter.
 */
#[FieldFormatter(
  id: 'container_queries_responsive_image',
  label: new TranslatableMarkup('Container queries responsive image'),
  field_types: [
    'image',
  ],
)]
class ContainerQueriesResponsiveImageFormatter extends ResponsiveImageFormatter {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $responsive_image_options = [];
    /** @var \Drupal\responsive_image\ResponsiveImageStyleInterface[] $responsive_image_styles */
    $responsive_image_styles = $this->responsiveImageStyleStorage->loadMultiple();
    \uasort($responsive_image_styles, '\Drupal\responsive_image\Entity\ResponsiveImageStyle::sort');
    foreach ($responsive_image_styles as $machine_name => $responsive_image_style) {
      $break_point_group = $responsive_image_style->get('breakpoint_group');
      if ($responsive_image_style->hasImageStyleMappings() && $break_point_group == 'cqri') {
        $responsive_image_options[$machine_name] = $responsive_image_style->label();
      }
    }

    // @todo if no suitable responsive image style is found, should we display
    // an error?
    if (!empty($responsive_image_options)) {
      $elements['responsive_image_style']['#options'] = $responsive_image_options;
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $view_elements = parent::viewElements($items, $langcode);

    foreach ($view_elements as $key => $item) {
      $view_elements[$key]['#theme'] = 'cqri_formatter';
    }

    return $view_elements;
  }

}
